@@ -1,12 +1,14 @@
 package Sah::Schema::url;
 
-our $DATE = '2019-07-25'; # DATE
-our $VERSION = '0.010'; # VERSION
+# AUTHOR
+our $DATE = '2019-11-29'; # DATE
+our $DIST = 'Sah-Schemas-URL'; # DIST
+our $VERSION = '0.011'; # VERSION
 
 our $schema = ['obj', {
     summary => 'URL string',
     isa => 'URI',
-    'x.perl.coerce_rules' => ['str_url'],
+    'x.perl.coerce_rules' => ['From_str::url'],
 }, {}];
 
 1;
@@ -24,7 +26,7 @@ Sah::Schema::url - URL string
 
 =head1 VERSION
 
-This document describes version 0.010 of Sah::Schema::url (from Perl distribution Sah-Schemas-URL), released on 2019-07-25.
+This document describes version 0.011 of Sah::Schema::url (from Perl distribution Sah-Schemas-URL), released on 2019-11-29.
 
 =head1 HOMEPAGE
 
